/*----------------------------------------------------------------------------------------------------------------------------------------
 * httpclient.cpp - http client
 *
 * Copyright (c) 2017 Frank Meyer - frank(at)fli4l.de
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *----------------------------------------------------------------------------------------------------------------------------------------
 */
#include <ESP8266WiFi.h>

static WiFiClient      client;

int
httpclient (const char * host, const char * path)
{
    const int       port = 80;
    int                cnt = 0;
    int                ch;

    if (! client.connect(host, port))
    {
        return -1;
    }

    client.print (String("GET ") + path + " HTTP/1.1\r\n" + "Host: " + host + "\r\n" + "Connection: close\r\n\r\n");

    unsigned long timeout = millis();

    while (client.available() == 0)
    {
        if (millis() - timeout > 5000)
        {
            client.stop();
            return -1;
        }
    }
    
    while(client.available())                           // skip http header
    {
        ch = client.read();

        if (ch == '\n')
        {
            if (cnt == 0)
            {
                break;
            }
            cnt = 0;
        }
        else if (ch != '\r')
        {
            cnt++;
        }
    }
    return 0;
}

int
httpclient_read (void)
{
    int        ch = -1;

    if (client.available())
    {
        ch = client.read();
    }
    return ch;
}

bool
httpclient_read_line(String& line, uint max_size) {
    int c;
    ulong _startMillis = 0;
    ulong _ellapsedMs = 0;
    line = "";
    int length = 1;

    if (max_size == 0)
    {
    	return false;
    }

    do {
    	_startMillis = millis();
        c = client.read();
        _ellapsedMs = (millis() - _startMillis);
        if (c >= 0 && c != '\n' && c != '\r') {
        	line += (char) c;
        	length++;
        }
    } while (((length) < max_size) && (c >= 0) && (c != '\r') && (_ellapsedMs < 1000));
    yield();
    return (c >= 0) && (_ellapsedMs < 1000);
}

void
httpclient_stop (void)
{
    client.stop ();
}
